Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: media/filters/audio_renderer_algorithm_base.h

Issue 155615: Modify ARAB to use simpler data types in FillBuffer() calls. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/filters/audio_renderer_algorithm_default.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/audio_renderer_algorithm_base.h
===================================================================
--- media/filters/audio_renderer_algorithm_base.h (revision 20829)
+++ media/filters/audio_renderer_algorithm_base.h (working copy)
@@ -33,7 +33,6 @@
namespace media {
class Buffer;
-class DataBuffer;
class AudioRendererAlgorithmBase {
public:
@@ -50,10 +49,10 @@
float initial_playback_rate,
RequestReadCallback* callback);
- // Implement this strategy method in derived classes. Fills |buffer_out| with
- // possibly scaled data from our |queue_|. |buffer_out| must be initialized
- // and have a datasize. Returns the number of bytes copied into |buffer_out|.
- virtual size_t FillBuffer(DataBuffer* buffer_out) = 0;
+ // Implement this strategy method in derived classes. Tries to fill |length|
+ // bytes of |dest| with possibly scaled data from our |queue_|. Returns the
+ // number of bytes copied into |dest|.
+ virtual size_t FillBuffer(uint8* dest, size_t length) = 0;
// Clears |queue_|.
virtual void FlushBuffers();
« no previous file with comments | « no previous file | media/filters/audio_renderer_algorithm_default.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698